triton-ascend
A language and compiler for custom Deep Learning operations on Ascend hardwares
What it is and what it does
Triton Ascend is a compiler framework that translates Triton code—a Python-like language for writing custom deep learning kernels—into optimized machine code for Ascend hardware. Developers write kernels by specifying tile/block decomposition and block-level computation logic; the compiler automatically handles memory layout, data movement, and pipeline parallelism, reducing operator development complexity.
The framework targets Ascend accelerators (Atlas 800T/I A2 products) on Ubuntu Linux with x86_64 or ARM host CPUs. It supports Triton Python API, continuous memory access patterns, and atomic operations. The project is actively maintained, with recent updates adding Scan/Sort operators, non-contiguous memory access, and compatibility with open-source repositories.
Use it for:
- Develop fused kernels (softmax, layer norm, attention) for Ascend-based inference or training without hand-coding low-level hardware operations.
- Port existing Triton kernels from GPU platforms to Ascend by adapting memory access patterns and API constraints.
- Implement custom matrix multiplication and tensor operations optimized for Ascend's memory hierarchy using Triton's autotune capability.
- Build high-performance operators for large language model inference on Ascend hardware with reduced development effort.
- Profile and optimize Triton kernels on Ascend using MindStudio tools for performance tuning and memory safety.
Worth the install?
AI-flagged interpretation of the facts on this page — verify before relying
Triton Ascend is a compiler framework that enables Triton code to run efficiently on Ascend hardware, handling memory allocation, data movement, and kernel optimization automatically.
Yes, if you develop on Ascend hardware and want to write custom kernels with reduced complexity compared to native operator development. No, if you target GPU or CPU platforms—this is Ascend-specific. The package is actively maintained and has no known vulnerabilities, but license metadata is unclear and Python version support is unspecified, so verify compatibility with your environment before committing.
Install
triton-ascend on PyPI
pip
pip install triton-ascenduv
uv add triton-ascendpoetry
poetry add triton-ascendInstalling triton-ascend
Before you install
Medium install friction due to platform-specific wheels (x86_64 and aarch64 Linux only, Python 3.10 and 3.11 supported). No runtime dependencies, but requires Ascend hardware and Ubuntu Linux host to be useful.
License in practice
License treatment is unclear—the description references MIT licensing, but the fact sheet does not confirm SPDX or raw license metadata, so actual licensing terms cannot be verified from this data.
Quickstart
pip install triton-ascend==3.2.0
import triton
import triton.language as tl
@triton.jit
def kernel(x_ptr, y_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
pid = tl.program_id(axis=0)
block_start = pid * BLOCK_SIZE
offsets = block_start + tl.arange(0, BLOCK_SIZE)
x = tl.load(x_ptr + offsets)
y = x + 1
tl.store(y_ptr + offsets, y)
Requires Ascend hardware (Atlas 800T/I A2 product line), Ubuntu Linux host, and x86_64 or aarch64 CPU architecture.
Verify before relying
- Exact Python version support—wheels exist for cp39, cp310, cp311 but requires_python is unspecified
- Whether the Triton Python API coverage claim is current as of version 3.2.0
- Performance characteristics and optimization guarantees compared to native Ascend operator development
- Pre-integration status with vLLM, sglang, and Flaggems mentioned in roadmap
Package facts
| License | not declared (unclear) |
| Python support | not specified |
| Install friction | medium — platform-specific wheel |
| Runtime dependencies | none |
| Maintenance | aging — 205 days since the last release |
| First released | |
| Downloads | 180,192/month — #10,152 on PyPI (30-day window, as of 2026-08-14) |
| Known vulnerabilities | none known (OSV.dev, checked 2026-08-14) |
Evidence: triton_ascend-3.2.0-cp310-cp310-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp310-cp310-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton_ascend-3.2.0-cp311-cp311-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp311-cp311-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl; triton_ascend-3.2.0-cp39-cp39-manylinux_2_27_aarch64.manylinux_2_28_aarch64.whl; triton_ascend-3.2.0-cp39-cp39-manylinux_2_27_x86_64.manylinux_2_28_x86_64.whl
Keywords: Compiler, Deep Learning
Tags
More Artificial Intelligence packages
LiteLLM provides a unified Python interface to…
permissive · top 100 on PyPI
huggingface-hubClient library and CLI tool for downloading,…
permissive · top 100 on PyPI
langchainLangChain provides a framework for building…
permissive · top 1,000 on PyPI
hf-xethf-xet provides chunk-based deduplication and…
permissive · top 1,000 on PyPI
tokenizersTokenizers converts raw text into token…
permissive · top 1,000 on PyPI
transformersTransformers provides a unified framework for…
permissive · top 1,000 on PyPI
helionHelion is a Python-embedded domain-specific…
unclear · top 15,000 on PyPI
tokenspeed-tritonTriton is a language and compiler for writing…
permissive · top 5,000 on PyPI
triton-windowsTriton-windows is a Windows port of the Triton…
permissive · top 15,000 on PyPI
tritonTriton is a language and compiler for writing…
permissive · top 1,000 on PyPI
liger-kernelLiger Kernel provides optimized Triton kernels…
permissive · top 15,000 on PyPI
tokamaxTokamax provides custom accelerator kernels for…
permissive · top 15,000 on PyPI
flash-attnProvides optimized GPU implementations of…
permissive · top 15,000 on PyPI
tilelangTilelang is a domain-specific language for…
permissive · top 5,000 on PyPI
quadrantsQuadrants is a high-performance compiler that…
permissive · top 15,000 on PyPI
torch-npuEnables PyTorch to run computations on Huawei…
permissive · top 5,000 on PyPI